==> openpmd-api-0.3.0a-py36he980bc4_0.tar.bz2: include/openPMD/IO/HDF5/ParallelHDF5IOHandler.hpp <==
/* Copyright 2017-2018 Fabian Koller
 *
 * This file is part of openPMD-api.
 *
 * openPMD-api is free software: you can redistribute it and/or modify
 * it under the terms of of either the GNU General Public License or
 * the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * openPMD-api is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License and the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License
 * and the GNU Lesser General Public License along with openPMD-api.
 * If not, see <http://www.gnu.org/licenses/>.
 */
#pragma once

#include "openPMD/IO/AbstractIOHandler.hpp"

#if openPMD_HAVE_MPI
#   include <mpi.h>
#   if openPMD_HAVE_HDF5
#       include "openPMD/IO/HDF5/HDF5IOHandler.hpp"
#   endif
#endif

#include <future>
#include <memory>
#include <string>


namespace openPMD
{
#if openPMD_HAVE_HDF5 && openPMD_HAVE_MPI
class ParallelHDF5IOHandler;

class ParallelHDF5IOHandlerImpl : public HDF5IOHandlerImpl
{
public:
    ParallelHDF5IOHandlerImpl(AbstractIOHandler*, MPI_Comm);
    virtual ~ParallelHDF5IOHandlerImpl();

    MPI_Comm m_mpiComm;
    MPI_Info m_mpiInfo;
};  //ParallelHDF5IOHandlerImpl
#else
class ParallelHDF5IOHandlerImpl
{ };
#endif

class ParallelHDF5IOHandler : public AbstractIOHandler
{
public:
#if openPMD_HAVE_MPI
    ParallelHDF5IOHandler(std::string const& path, AccessType, MPI_Comm);
#else
    ParallelHDF5IOHandler(std::string const& path, AccessType);
#endif
    virtual ~ParallelHDF5IOHandler() override;

    std::future< void > flush() override;

private:
    std::unique_ptr< ParallelHDF5IOHandlerImpl > m_impl;
};  //ParallelHDF5IOHandler
} // openPMD

==> openpmd-api-0.3.1a-py36he980bc4_0.tar.bz2: include/openPMD/IO/HDF5/ParallelHDF5IOHandler.hpp <==
/* Copyright 2017-2018 Fabian Koller
 *
 * This file is part of openPMD-api.
 *
 * openPMD-api is free software: you can redistribute it and/or modify
 * it under the terms of of either the GNU General Public License or
 * the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * openPMD-api is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License and the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License
 * and the GNU Lesser General Public License along with openPMD-api.
 * If not, see <http://www.gnu.org/licenses/>.
 */
#pragma once

#include "openPMD/IO/AbstractIOHandler.hpp"

#include <future>
#include <memory>
#include <string>


namespace openPMD
{
    class ParallelHDF5IOHandlerImpl;

    class ParallelHDF5IOHandler : public AbstractIOHandler
    {
    public:
    #if openPMD_HAVE_MPI
        ParallelHDF5IOHandler(std::string const& path, AccessType, MPI_Comm);
    #else
        ParallelHDF5IOHandler(std::string const& path, AccessType);
    #endif
        virtual ~ParallelHDF5IOHandler() override;

        std::future< void > flush() override;

    private:
        std::unique_ptr< ParallelHDF5IOHandlerImpl > m_impl;
    }; // ParallelHDF5IOHandler
} // openPMD
